django_analyses.serializers.input.definitions package — django_analyses 0.0.3 documentation

# django_analyses.serializers.input.definitions package

## Submodules

## django_analyses.serializers.input.definitions.boolean_input_definition module

class `django_analyses.serializers.input.definitions.boolean_input_definition.` `BooleanInputDefinitionSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.ModelSerializer`

  class `Meta`

    Bases: `object`

    `fields` = '__all__'
    `model`

      alias of `django_analyses.models.input.definitions.boolean_input_definition.BooleanInputDefinition`

## django_analyses.serializers.input.definitions.directory_input_definition module

class `django_analyses.serializers.input.definitions.directory_input_definition.` `DirectoryInputDefinitionSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.ModelSerializer`

  class `Meta`

    Bases: `object`

    `fields` = '__all__'
    `model`

      alias of `django_analyses.models.input.definitions.directory_input_definition.DirectoryInputDefinition`

## django_analyses.serializers.input.definitions.file_input_definition module

class `django_analyses.serializers.input.definitions.file_input_definition.` `FileInputDefinitionSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.ModelSerializer`

  class `Meta`

    Bases: `object`

    `fields` = '__all__'
    `model`

      alias of `django_analyses.models.input.definitions.file_input_definition.FileInputDefinition`

## django_analyses.serializers.input.definitions.float_input_definition module

class `django_analyses.serializers.input.definitions.float_input_definition.` `FloatInputDefinitionSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.ModelSerializer`

  class `Meta`

    Bases: `object`

    `fields` = '__all__'
    `model`

      alias of `django_analyses.models.input.definitions.float_input_definition.FloatInputDefinition`

## django_analyses.serializers.input.definitions.input_definition module

class `django_analyses.serializers.input.definitions.input_definition.` `InputDefinitionSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `django_analyses.serializers.utils.polymorphic.PolymorphicSerializer`

  class `Meta`

    Bases: `object`

    `fields` = '__all__'
    `model`

      alias of `django_analyses.models.input.definitions.input_definition.InputDefinition`

  `get_serializer`(input_type: str) → rest_framework.serializers.Serializer

    Return a dict to map class names to their respective serializer classes. To be implemented by all PolymorphicSerializer subclasses.

`django_analyses.serializers.input.definitions.input_definition.` `get_extra_input_definition_serializers`() → dict

## django_analyses.serializers.input.definitions.integer_input_definition module

class `django_analyses.serializers.input.definitions.integer_input_definition.` `IntegerInputDefinitionSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.ModelSerializer`

  class `Meta`

    Bases: `object`

    `fields` = '__all__'
    `model`

      alias of `django_analyses.models.input.definitions.integer_input_definition.IntegerInputDefinition`

## django_analyses.serializers.input.definitions.list_input_definition module

class `django_analyses.serializers.input.definitions.list_input_definition.` `ListInputDefinitionSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.ModelSerializer`

  class `Meta`

    Bases: `object`

    `fields` = '__all__'
    `model`

      alias of `django_analyses.models.input.definitions.list_input_definition.ListInputDefinition`

## django_analyses.serializers.input.definitions.string_input_definition module

class `django_analyses.serializers.input.definitions.string_input_definition.` `StringInputDefinitionSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.ModelSerializer`

  class `Meta`

    Bases: `object`

    `fields` = '__all__'
    `model`

      alias of `django_analyses.models.input.definitions.string_input_definition.StringInputDefinition`

## Module contents